@@ -60,7 +60,7 @@ usage(void);
 static void
 usage(void) {
 	fprintf(stderr,
-		"usage: %s [-achijlvz] [-p [-x]] [-t directory] "
+		"usage: %s [-achijklvz] [-p [-x]] [-t directory] "
 		"[named.conf]\n",
 		program);
 	exit(EXIT_SUCCESS);
@@ -606,7 +606,7 @@ main(int argc, char **argv) {
 	/*
 	 * Process memory debugging argument first.
 	 */
-#define CMDLINE_FLAGS "acdhijlm:t:pvxz"
+#define CMDLINE_FLAGS "acdhijklm:t:pvxz"
 	while ((c = isc_commandline_parse(argc, argv, CMDLINE_FLAGS)) != -1) {
 		switch (c) {
 		case 'm':
@@ -653,6 +653,10 @@ main(int argc, char **argv) {
 			nomerge = false;
 			break;
 
+		case 'k':
+			checkflags |= BIND_CHECK_KEYS;
+			break;
+
 		case 'l':
 			list_zones = true;
 			break;
