@@ -36,6 +36,7 @@
 #include <unistd.h>
 
 #include <isc/buffer.h>
+#include <isc/errno.h>
 #include <isc/file.h>
 #include <isc/result.h>
 #include <isc/strerr.h>
@@ -60,6 +61,7 @@ static int devnullfd = -1;
 static struct passwd *runas_pw = NULL;
 static bool done_setuid = false;
 static int dfd[2] = { -1, -1 };
+static int notify_fd = -1;
 
 static uid_t saved_uid = (uid_t)-1;
 static gid_t saved_gid = (gid_t)-1;
@@ -273,6 +275,74 @@ setperms(uid_t uid, gid_t gid) {
 	}
 }
 
+#ifdef __linux__
+static isc_result_t
+connect_systemd_notify_unix(char *path) {
+	struct sockaddr_un addr;
+	isc_result_t result = ISC_R_SUCCESS;
+	size_t len;
+
+	addr.sun_family = AF_UNIX;
+
+	len = strlcpy(addr.sun_path, path, sizeof(addr.sun_path));
+	if (len >= sizeof(addr.sun_path)) {
+		return ISC_R_NOSPACE;
+	}
+
+	/* Convert abstract unix sockets */
+	if (addr.sun_path[0] == '@') {
+		addr.sun_path[0] = '\0';
+	}
+
+	notify_fd = socket(AF_UNIX, SOCK_DGRAM | SOCK_CLOEXEC, 0);
+	if (notify_fd < 0) {
+		return isc_errno_toresult(errno);
+	}
+
+	if (connect(notify_fd, (struct sockaddr *)&addr, sizeof(addr)) == -1) {
+		result = isc_errno_toresult(errno);
+		close(notify_fd);
+		notify_fd = -1;
+	}
+
+	return result;
+}
+
+static void
+setup_systemd_notify(void) {
+	isc_result_t result;
+	char *path;
+
+	REQUIRE(notify_fd == -1);
+
+	path = getenv("NOTIFY_SOCKET");
+
+	/* systemd notification is not set, oh well. */
+	if (path == NULL) {
+		return;
+	}
+
+	if (path[0] == '/' || path[0] == '@') {
+		result = connect_systemd_notify_unix(path);
+	} else if (strncmp(path, "vsock", 5) == 0) {
+		result = ISC_R_FAMILYNOSUPPORT;
+	} else {
+		result = ISC_R_INVALIDPROTO;
+	}
+
+	if (result != ISC_R_SUCCESS) {
+		RUNTIME_CHECK(notify_fd == -1);
+		named_main_earlywarning(
+			"failed to connect to notification socket '%s': %s",
+			path, isc_result_totext(result));
+	} else {
+		RUNTIME_CHECK(notify_fd != -1);
+	}
+}
+#else /* __linux__ */
+#define setup_systemd_notify(...)
+#endif /* __linux__ */
+
 static void
 setup_syslog(const char *progname) {
 	int options;
@@ -287,6 +357,7 @@ setup_syslog(const char *progname) {
 void
 named_os_init(const char *progname) {
 	setup_syslog(progname);
+	setup_systemd_notify();
 #if HAVE_LIBCAP
 	linux_initialprivs();
 #endif /* HAVE_LIBCAP */
@@ -362,6 +433,13 @@ named_os_daemonize(void) {
 			(void)dup2(devnullfd, STDERR_FILENO);
 		}
 	}
+
+	/*
+	 * Will be closed from SOCK_CLOEXEC but should be set to -1 again before
+	 * reconnecting to the notification socket.
+	 */
+	notify_fd = -1;
+	setup_systemd_notify();
 }
 
 void
@@ -400,15 +478,15 @@ named_os_closedevnull(void) {
 static bool
 all_digits(const char *s) {
 	if (*s == '\0') {
-		return (false);
+		return false;
 	}
 	while (*s != '\0') {
 		if (!isdigit((unsigned char)(*s))) {
-			return (false);
+			return false;
 		}
 		s++;
 	}
-	return (true);
+	return true;
 }
 
 void
@@ -521,9 +599,9 @@ named_os_changeuser(bool permanent) {
 uid_t
 named_os_uid(void) {
 	if (runas_pw == NULL) {
-		return (0);
+		return 0;
 	}
-	return (runas_pw->pw_uid);
+	return runas_pw->pw_uid;
 }
 
 void
@@ -587,22 +665,22 @@ safe_open(const char *filename, mode_t mode, bool append) {
 
 	if (stat(filename, &sb) == -1) {
 		if (errno != ENOENT) {
-			return (-1);
+			return -1;
 		}
 	} else if ((sb.st_mode & S_IFREG) == 0) {
 		errno = EOPNOTSUPP;
-		return (-1);
+		return -1;
 	}
 
 	if (append) {
 		fd = open(filename, O_WRONLY | O_CREAT | O_APPEND, mode);
 	} else {
 		if (unlink(filename) < 0 && errno != ENOENT) {
-			return (-1);
+			return -1;
 		}
 		fd = open(filename, O_WRONLY | O_CREAT | O_EXCL, mode);
 	}
-	return (fd);
+	return fd;
 }
 
 static void
@@ -650,7 +728,7 @@ mkdirpath(char *filename, void (*report)(const char *, ...)) {
 			    !strcmp(slash + 1, ".."))
 			{
 				*slash = '/';
-				return (0);
+				return 0;
 			}
 			mode = S_IRUSR | S_IWUSR | S_IXUSR; /* u=rwx */
 			mode |= S_IRGRP | S_IXGRP;	    /* g=rx */
@@ -672,11 +750,11 @@ mkdirpath(char *filename, void (*report)(const char *, ...)) {
 		}
 		*slash = '/';
 	}
-	return (0);
+	return 0;
 
 error:
 	*slash = '/';
-	return (-1);
+	return -1;
 }
 
 FILE *
@@ -693,11 +771,11 @@ named_os_openfile(const char *filename, mode_t mode, bool switch_user) {
 		strerror_r(errno, strbuf, sizeof(strbuf));
 		named_main_earlywarning("couldn't strdup() '%s': %s", filename,
 					strbuf);
-		return (NULL);
+		return NULL;
 	}
 	if (mkdirpath(f, named_main_earlywarning) == -1) {
 		free(f);
-		return (NULL);
+		return NULL;
 	}
 	free(f);
 
@@ -737,7 +815,7 @@ named_os_openfile(const char *filename, mode_t mode, bool switch_user) {
 		strerror_r(errno, strbuf, sizeof(strbuf));
 		named_main_earlywarning("could not open file '%s': %s",
 					filename, strbuf);
-		return (NULL);
+		return NULL;
 	}
 
 	fp = fdopen(fd, "w");
@@ -747,7 +825,7 @@ named_os_openfile(const char *filename, mode_t mode, bool switch_user) {
 					filename, strbuf);
 	}
 
-	return (fp);
+	return fp;
 }
 
 void
@@ -863,5 +941,40 @@ named_os_uname(void) {
 	if (unamep == NULL) {
 		getuname();
 	}
-	return (unamep);
+	return unamep;
 }
+
+#ifdef __linux__
+void
+named_os_notify_systemd(const char *restrict format, ...) {
+	char buffer[512];
+	va_list ap;
+	int len;
+
+	if (notify_fd == -1 || format == NULL) {
+		return;
+	}
+
+	va_start(ap, format);
+	len = vsnprintf(buffer, sizeof(buffer), format, ap);
+	va_end(ap);
+
+	/* Be very loud if notification is too long */
+	RUNTIME_CHECK(len > 0 && len < (int)sizeof(buffer));
+
+	if (write(notify_fd, buffer, len) != len) {
+		isc_log_write(named_g_lctx, NAMED_LOGCATEGORY_GENERAL,
+			      NAMED_LOGMODULE_MAIN, ISC_LOG_ERROR,
+			      "failed writing to notification socket '%s'",
+			      isc_result_totext(isc_errno_toresult(errno)));
+	}
+}
+
+void
+named_os_notify_close(void) {
+	if (notify_fd != -1) {
+		close(notify_fd);
+		notify_fd = -1;
+	}
+}
+#endif /* __linux__ */
