@@ -11,27 +11,25 @@
 
 import pytest
 
+import isctest
+import isctest.mark
+
 from filters.common import (
     ARTIFACTS,
     check_filter,
     check_filter_other_family,
     prime_cache,
+    reconfigure_servers,
 )
 
-import isctest.mark
 
 pytestmark = pytest.mark.extra_artifacts(ARTIFACTS)
 
 
-def bootstrap():
-    return {
-        "family": "v4",
-        "filtertype": "aaaa",
-    }
-
-
 @pytest.fixture(scope="module", autouse=True)
-def after_servers_start():
+def setup_filters(servers, templates):
+    isctest.log.info("configuring server to filter AAAA on V4")
+    reconfigure_servers("aaaa", "v4", servers, templates)
     prime_cache("10.53.0.2")
     prime_cache("10.53.0.3")
 
