@@ -11,13 +11,13 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
-import os
 from pathlib import Path
 from typing import Any, Dict, Optional, Union
 
-import pytest
+import jinja2
 
 from .log import debug
+from .vars import ALL
 
 
 class TemplateEngine:
@@ -25,39 +25,20 @@ class TemplateEngine:
     Engine for rendering jinja2 templates in system test directories.
     """
 
-    def __init__(self, directory: Union[str, Path], env_vars=None):
+    def __init__(self, directory: Union[str, Path], env_vars=ALL):
         """
         Initialize the template engine for `directory`, optionally overriding
         the `env_vars` that will be used when rendering the templates (defaults
         to the environment variables set by the pytest runner).
         """
         self.directory = Path(directory)
-        self._j2env = None
-        if env_vars is None:
-            self.env_vars = dict(os.environ)
-        else:
-            self.env_vars = dict(env_vars)
-
-    @property
-    def j2env(self):
-        """
-        Jinja2 engine that is initialized when first requested. In case the
-        jinja2 package in unavailable, the current test will be skipped.
-        """
-        if self._j2env is None:
-            try:
-                import jinja2  # pylint: disable=import-outside-toplevel
-            except ImportError:
-                pytest.skip("jinja2 not found")
-
-            loader = jinja2.FileSystemLoader(str(self.directory))
-            return jinja2.Environment(
-                loader=loader,
-                undefined=jinja2.StrictUndefined,
-                variable_start_string="@",
-                variable_end_string="@",
-            )
-        return self._j2env
+        self.env_vars = dict(env_vars)
+        self.j2env = jinja2.Environment(
+            loader=jinja2.FileSystemLoader(str(self.directory)),
+            undefined=jinja2.StrictUndefined,
+            variable_start_string="@",
+            variable_end_string="@",
+        )
 
     def render(
         self,
@@ -87,14 +68,14 @@ class TemplateEngine:
         stream = self.j2env.get_template(template).stream(data)
         stream.dump(output, encoding="utf-8")
 
-    def render_auto(self, data: Optional[Dict[str, Any]] = None):
+    def render_auto(self):
         """
-        Render all *.j2 templates with default (and optionally the provided)
-        values and write the output to files without the .j2 extensions.
+        Render all *.j2 templates with default values and write the output to
+        files without the .j2 extensions.
         """
         templates = [
             str(filepath.relative_to(self.directory))
             for filepath in self.directory.rglob("*.j2")
         ]
         for template in templates:
-            self.render(template[:-3], data)
+            self.render(template[:-3])
