@@ -9,33 +9,38 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
-from rollover.common import CDSS, DEFAULT_CONFIG, ROLLOVER_MARK
+# pylint: disable=redefined-outer-name,unused-import
 
 import isctest
-
-pytestmark = ROLLOVER_MARK
+from rollover.common import (
+    pytestmark,
+    alg,
+    size,
+    CDSS,
+    DEFAULT_CONFIG,
+)
 
 
-def test_dynamic2inline(ns3, default_algorithm, templates):
+def test_dynamic2inline(alg, size, ns6, templates):
     config = DEFAULT_CONFIG
     policy = "default"
     zone = "dynamic2inline.kasp"
 
-    isctest.kasp.wait_keymgr_done(ns3, zone)
+    isctest.kasp.wait_keymgr_done(ns6, zone)
 
     step = {
         "zone": zone,
         "cdss": CDSS,
         "keyprops": [
-            f"csk unlimited {default_algorithm.number} {default_algorithm.bits} goal:omnipresent dnskey:rumoured krrsig:rumoured zrrsig:rumoured ds:hidden",
+            f"csk unlimited {alg} {size} goal:omnipresent dnskey:rumoured krrsig:rumoured zrrsig:rumoured ds:hidden",
         ],
         "nextev": None,
     }
 
-    isctest.kasp.check_rollover_step(ns3, config, policy, step)
+    isctest.kasp.check_rollover_step(ns6, config, policy, step)
 
-    templates.render("ns3/named.conf", {"change_lifetime": True})
-    ns3.reconfigure()
-    isctest.kasp.wait_keymgr_done(ns3, zone, reconfig=True)
+    templates.render("ns6/named.conf", {"change_lifetime": True})
+    ns6.reconfigure()
+    isctest.kasp.wait_keymgr_done(ns6, zone, reconfig=True)
 
-    isctest.kasp.check_rollover_step(ns3, config, policy, step)
+    isctest.kasp.check_rollover_step(ns6, config, policy, step)
