@@ -39,7 +39,7 @@ LLVMFuzzerInitialize(int *argc ISC_ATTR_UNUSED, char ***argv ISC_ATTR_UNUSED) {
 	isc_mem_create(&mctx);
 	output = isc_mem_get(mctx, output_len);
 
-	return (0);
+	return 0;
 }
 
 static isc_result_t
@@ -60,7 +60,7 @@ parse_message(isc_buffer_t *input, dns_message_t **messagep) {
 		dns_message_detach(&message);
 	}
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -85,7 +85,7 @@ print_message(dns_message_t *message) {
 			output);
 	}
 
-	return (result);
+	return result;
 }
 
 #define CHECKRESULT(r, f)                 \
@@ -135,11 +135,11 @@ render_message(dns_message_t **messagep) {
 
 	result = parse_message(&buffer, messagep);
 
-	return (result);
+	return result;
 
 cleanup:
 	dns_compress_invalidate(&cctx);
-	return (result);
+	return result;
 }
 
 int
@@ -149,7 +149,7 @@ LLVMFuzzerTestOneInput(const uint8_t *data, size_t size) {
 	dns_message_t *message = NULL;
 
 	if (size > 65535) {
-		return (0);
+		return 0;
 	}
 
 	isc_buffer_constinit(&buffer, data, size);
@@ -181,5 +181,5 @@ cleanup:
 		dns_message_detach(&message);
 	}
 
-	return (0);
+	return 0;
 }
