@@ -28,7 +28,7 @@ fromtext_brid(ARGS_FROMTEXT) {
 	UNUSED(options);
 	UNUSED(callbacks);
 
-	return isc_base64_tobuffer(lexer, target, -2);
+	return isc_base64_tobuffer(lexer, target, -1);
 }
 
 static isc_result_t
@@ -45,6 +45,8 @@ totext_brid(ARGS_TOTEXT) {
 		RETERR(str_totext(" (", target));
 	}
 
+	RETERR(str_totext(tctx->linebreak, target));
+
 	if (tctx->width == 0) { /* No splitting */
 		RETERR(isc_base64_totext(&sr, 60, "", target));
 	} else {
@@ -67,7 +69,6 @@ fromwire_brid(ARGS_FROMWIRE) {
 
 	UNUSED(type);
 	UNUSED(rdclass);
-	UNUSED(options);
 	UNUSED(dctx);
 
 	isc_buffer_activeregion(source, &sr);
@@ -83,7 +84,7 @@ fromwire_brid(ARGS_FROMWIRE) {
 static isc_result_t
 towire_brid(ARGS_TOWIRE) {
 	REQUIRE(rdata->type == dns_rdatatype_brid);
-	REQUIRE(rdata->length > 0);
+	REQUIRE(rdata->length >= 3);
 
 	UNUSED(cctx);
 
