@@ -28,12 +28,12 @@ isc_parse_uint32(uint32_t *uip, const char *string, int base) {
 	uint32_t r;
 	char *e;
 	if (!isalnum((unsigned char)(string[0]))) {
-		return (ISC_R_BADNUMBER);
+		return ISC_R_BADNUMBER;
 	}
 	errno = 0;
 	n = strtoul(string, &e, base);
 	if (*e != '\0') {
-		return (ISC_R_BADNUMBER);
+		return ISC_R_BADNUMBER;
 	}
 	/*
 	 * Where long is 64 bits we need to convert to 32 bits then test for
@@ -42,10 +42,10 @@ isc_parse_uint32(uint32_t *uip, const char *string, int base) {
 	 */
 	r = (uint32_t)n;
 	if ((n == ULONG_MAX && errno == ERANGE) || (n != (unsigned long)r)) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	*uip = r;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -54,13 +54,13 @@ isc_parse_uint16(uint16_t *uip, const char *string, int base) {
 	isc_result_t result;
 	result = isc_parse_uint32(&val, string, base);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	if (val > 0xFFFF) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	*uip = (uint16_t)val;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -69,11 +69,11 @@ isc_parse_uint8(uint8_t *uip, const char *string, int base) {
 	isc_result_t result;
 	result = isc_parse_uint32(&val, string, base);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	if (val > 0xFF) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	*uip = (uint8_t)val;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
