@@ -41,8 +41,7 @@ ISC_RUN_TEST_IMPL(isc_radix_remove) {
 
 	UNUSED(state);
 
-	result = isc_radix_create(mctx, &radix, 32);
-	assert_int_equal(result, ISC_R_SUCCESS);
+	isc_radix_create(mctx, &radix, 32);
 
 	in_addr.s_addr = inet_addr("1.1.1.1");
 	isc_netaddr_fromin(&netaddr, &in_addr);
@@ -90,8 +89,7 @@ ISC_RUN_TEST_IMPL(isc_radix_search) {
 
 	UNUSED(state);
 
-	result = isc_radix_create(mctx, &radix, 32);
-	assert_int_equal(result, ISC_R_SUCCESS);
+	isc_radix_create(mctx, &radix, 32);
 
 	in_addr.s_addr = inet_addr("3.3.3.0");
 	isc_netaddr_fromin(&netaddr, &in_addr);
